@@ -1,4 +1,4 @@
 utils::globalVariables(c("Cumulative Percent", "Percent", "Frequency",
                          "Valid Percent", "cum", "d.output", "deff",
                          "moe", "observations", "pct", "total", "valid.pct",
-                         "valid.total", "Response"))
+                         "valid.total", "Response", "unweighted_n"))
